aboutsummaryrefslogtreecommitdiffstats
path: root/admin/include/functions.php
diff options
context:
space:
mode:
Diffstat (limited to 'admin/include/functions.php')
-rw-r--r--admin/include/functions.php11
1 files changed, 7 insertions, 4 deletions
diff --git a/admin/include/functions.php b/admin/include/functions.php
index 002c1747a..3feebdb22 100644
--- a/admin/include/functions.php
+++ b/admin/include/functions.php
@@ -740,7 +740,7 @@ function is_user_allowed( $category_id, $restrictions )
/**
* returns an array containing sub-directories which can be a category
*
* directories nammed "thumbnail" are omitted
*
* @param string $basedir
* @return array
@@ -753,9 +753,12 @@ function get_category_directories( $basedir )
{
while ( $file = readdir( $opendir ) )
{
- if ( $file != '.' and $file != '..'
- and is_dir( $basedir.'/'.$file )
- and $file != 'thumbnail' )
+ if ($file != '.'
+ and $file != '..'
+ and $file != 'thumbnail'
+ and $file != 'high'
+ and $file != 'representative'
+ and is_dir($basedir.'/'.$file))
{
array_push( $sub_dirs, $file );
}
@@ -740,7 +740,7 @@ function is_user_allowed( $category_id, $restrictions )
* returns an array containing sub-directories which can be a category
*
- * directories nammed "thumbnail" are omitted
+ * directories nammed "thumbnail", "high" or "representative" are omitted
*
* @param string $basedir